@@ -1,12 +1,22 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the examples of the Qt Toolkit.
 **
 ** $QT_BEGIN_LICENSE:BSD$
-** You may use this file under the terms of the BSD license as follows:
+** Commercial License Usage
+** Licensees holding valid commercial Qt licenses may use this file in
+** accordance with the commercial license agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
+**
+** BSD License Usage
+** Alternatively, you may use this file under the terms of the BSD license
+** as follows:
 **
 ** "Redistribution and use in source and binary forms, with or without
 ** modification, are permitted provided that the following conditions are
@@ -17,8 +27,8 @@
 **     notice, this list of conditions and the following disclaimer in
 **     the documentation and/or other materials provided with the
 **     distribution.
-**   * Neither the name of Digia Plc and its Subsidiary(-ies) nor the names
-**     of its contributors may be used to endorse or promote products derived
+**   * Neither the name of The Qt Company Ltd nor the names of its
+**     contributors may be used to endorse or promote products derived
 **     from this software without specific prior written permission.
 **
 **
@@ -56,15 +66,15 @@ class MultiPageWidgetContainerExtension: public QObject,
     Q_INTERFACES(QDesignerContainerExtension)
 
 public:
-    MultiPageWidgetContainerExtension(MultiPageWidget *widget, QObject *parent);
+    explicit MultiPageWidgetContainerExtension(MultiPageWidget *widget, QObject *parent);
 
-    void addWidget(QWidget *widget);
-    int count() const;
-    int currentIndex() const;
-    void insertWidget(int index, QWidget *widget);
-    void remove(int index);
-    void setCurrentIndex(int index);
-    QWidget *widget(int index) const;
+    void addWidget(QWidget *widget) Q_DECL_OVERRIDE;
+    int count() const Q_DECL_OVERRIDE;
+    int currentIndex() const Q_DECL_OVERRIDE;
+    void insertWidget(int index, QWidget *widget) Q_DECL_OVERRIDE;
+    void remove(int index) Q_DECL_OVERRIDE;
+    void setCurrentIndex(int index) Q_DECL_OVERRIDE;
+    QWidget *widget(int index) const Q_DECL_OVERRIDE;
 
 private:
     MultiPageWidget *myWidget;
