@@ -1,31 +1,26 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the Qt Assistant of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL21$
+** $QT_BEGIN_LICENSE:GPL-EXCEPT$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** As a special exception, The Qt Company gives you certain additional
-** rights. These rights are described in The Qt Company LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3 as published by the Free Software
+** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -39,8 +34,11 @@
 #include "openpagesmanager.h"
 #include "tracer.h"
 
+#include <QtCore/QAbstractListModel>
 #include <QtCore/QtAlgorithms>
 #include <QtCore/QFileSystemWatcher>
+#include <QtCore/QSortFilterProxyModel>
+#include <QtCore/QVector>
 
 #include <QtWidgets/QDesktopWidget>
 #include <QtWidgets/QFileDialog>
@@ -51,25 +49,114 @@
 
 #include <QtHelp/QHelpEngineCore>
 
+#include <algorithm>
+
 QT_BEGIN_NAMESPACE
 
+struct RegisteredDocEntry
+{
+    QString nameSpace;
+    QString fileName;
+};
+
+typedef QVector<RegisteredDocEntry> RegisteredDocEntries;
+
+class RegisteredDocsModel : public QAbstractListModel {
+public:
+
+    explicit RegisteredDocsModel(const RegisteredDocEntries &e = RegisteredDocEntries(), QObject *parent = nullptr)
+        : QAbstractListModel(parent), m_docEntries(e) {}
+
+    int rowCount(const QModelIndex & = QModelIndex()) const override { return m_docEntries.size(); }
+    QVariant data(const QModelIndex &index, int role) const override;
+
+    bool contains(const QString &nameSpace) const
+    {
+        return m_docEntries.cend() !=
+            std::find_if(m_docEntries.cbegin(), m_docEntries.cend(),
+                         [nameSpace] (const RegisteredDocEntry &e) { return e.nameSpace == nameSpace; });
+    }
+
+    void append(const RegisteredDocEntry &e);
+
+    const RegisteredDocEntries &docEntries() const { return m_docEntries; }
+    void setDocEntries(const RegisteredDocEntries &);
+
+private:
+    RegisteredDocEntries m_docEntries;
+};
+
+QVariant RegisteredDocsModel::data(const QModelIndex &index, int role) const
+{
+    QVariant result;
+    const int row = index.row();
+    if (index.isValid() && row < m_docEntries.size()) {
+        switch (role) {
+        case Qt::DisplayRole:
+            result = QVariant(m_docEntries.at(row).nameSpace);
+            break;
+        case Qt::ToolTipRole:
+            result = QVariant(QDir::toNativeSeparators(m_docEntries.at(row).fileName));
+            break;
+        default:
+            break;
+        }
+    }
+    return result;
+}
+
+void RegisteredDocsModel::append(const RegisteredDocEntry &e)
+{
+    beginInsertRows(QModelIndex(), m_docEntries.size(), m_docEntries.size());
+    m_docEntries.append(e);
+    endInsertRows();
+}
+
+void RegisteredDocsModel::setDocEntries(const RegisteredDocEntries &e)
+{
+    beginResetModel();
+    m_docEntries = e;
+    endResetModel();
+}
+
+static RegisteredDocEntries registeredDocEntries(const HelpEngineWrapper &wrapper)
+{
+    RegisteredDocEntries result;
+    const QStringList nameSpaces = wrapper.registeredDocumentations();
+    result.reserve(nameSpaces.size());
+    foreach (const QString &nameSpace, nameSpaces) {
+        RegisteredDocEntry entry;
+        entry.nameSpace = nameSpace;
+        entry.fileName = wrapper.documentationFileName(nameSpace);
+        result.append(entry);
+    }
+    return result;
+}
+
 PreferencesDialog::PreferencesDialog(QWidget *parent)
     : QDialog(parent)
     , m_appFontChanged(false)
     , m_browserFontChanged(false)
     , helpEngine(HelpEngineWrapper::instance())
+    , m_hideFiltersTab(!helpEngine.filterFunctionalityEnabled())
+    , m_hideDocsTab(!helpEngine.documentationManagerEnabled())
 {
     TRACE_OBJ
     m_ui.setupUi(this);
 
+    m_registeredDocsModel =
+        new RegisteredDocsModel(m_hideDocsTab ? RegisteredDocEntries() : registeredDocEntries(helpEngine));
+    m_registereredDocsFilterModel = new QSortFilterProxyModel(m_ui.registeredDocsListView);
+    m_registereredDocsFilterModel->setSourceModel(m_registeredDocsModel);
+    m_ui.registeredDocsListView->setModel(m_registereredDocsFilterModel);
+    connect(m_ui.registeredDocsFilterLineEdit, &QLineEdit::textChanged,
+            m_registereredDocsFilterModel, &QSortFilterProxyModel::setFilterFixedString);
+
     connect(m_ui.buttonBox->button(QDialogButtonBox::Ok), SIGNAL(clicked()),
         this, SLOT(applyChanges()));
     connect(m_ui.buttonBox->button(QDialogButtonBox::Cancel), SIGNAL(clicked()),
         this, SLOT(reject()));
 
-    m_hideFiltersTab = !helpEngine.filterFunctionalityEnabled();
-    m_hideDocsTab = !helpEngine.documentationManagerEnabled();
-
     if (!m_hideFiltersTab) {
         m_ui.attributeWidget->header()->hide();
         m_ui.attributeWidget->setRootIsDecorated(false);
@@ -97,8 +184,9 @@ PreferencesDialog::PreferencesDialog(QWidget *parent)
         connect(m_ui.docRemoveButton, SIGNAL(clicked()), this,
             SLOT(removeDocumentation()));
 
-        m_docsBackup = helpEngine.registeredDocumentations();
-        m_ui.registeredDocsListWidget->addItems(m_docsBackup);
+        m_docsBackup.reserve(m_registeredDocsModel->rowCount());
+        foreach (const RegisteredDocEntry &e, m_registeredDocsModel->docEntries())
+            m_docsBackup.append(e.nameSpace);
     } else {
         m_ui.tabWidget->removeTab(m_ui.tabWidget->indexOf(m_ui.docsTab));
     }
@@ -254,14 +342,16 @@ void PreferencesDialog::addDocumentationLocal()
             continue;
         }
 
-        if (m_ui.registeredDocsListWidget->findItems(nameSpace,
-            Qt::MatchFixedString).count()) {
+        if (m_registeredDocsModel->contains(nameSpace)) {
                 alreadyRegistered.append(nameSpace);
                 continue;
         }
 
         if (helpEngine.registerDocumentation(fileName)) {
-            m_ui.registeredDocsListWidget->addItem(nameSpace);
+            RegisteredDocEntry entry;
+            entry.nameSpace = nameSpace;
+            entry.fileName = fileName;
+            m_registeredDocsModel->append(entry);
             m_regDocs.append(nameSpace);
             m_unregDocs.removeAll(nameSpace);
         }
@@ -291,14 +381,28 @@ void PreferencesDialog::addDocumentationLocal()
     updateFilterPage();
 }
 
+QList<int> PreferencesDialog::currentRegisteredDocsSelection() const
+{
+    QList<int> result;
+    foreach (const QModelIndex &index, m_ui.registeredDocsListView->selectionModel()->selectedRows())
+        result.append(m_registereredDocsFilterModel->mapToSource(index).row());
+    return result;
+}
+
 void PreferencesDialog::removeDocumentation()
 {
     TRACE_OBJ
 
+    const QList<int> currentSelection = currentRegisteredDocsSelection();
+    if (currentSelection.isEmpty())
+        return;
+
+    RegisteredDocEntries entries = m_registeredDocsModel->docEntries();
+
     bool foundBefore = false;
-    QList<QListWidgetItem*> l = m_ui.registeredDocsListWidget->selectedItems();
-    foreach (QListWidgetItem* item, l) {
-        const QString& ns = item->text();
+    for (int i = currentSelection.size() - 1; i >= 0; --i) {
+        const int row = currentSelection.at(i);
+        const QString& ns = entries.at(row).nameSpace;
         if (!foundBefore && OpenPagesManager::instance()->pagesOpenForNamespace(ns)) {
             if (0 == QMessageBox::information(this, tr("Remove Documentation"),
                 tr("Some documents currently opened in Assistant reference the "
@@ -309,13 +413,15 @@ void PreferencesDialog::removeDocumentation()
         }
 
         m_unregDocs.append(ns);
-        delete m_ui.registeredDocsListWidget->takeItem(
-            m_ui.registeredDocsListWidget->row(item));
+        entries.removeAt(row);
     }
 
-    if (m_ui.registeredDocsListWidget->count()) {
-        m_ui.registeredDocsListWidget->setCurrentRow(0,
-            QItemSelectionModel::ClearAndSelect);
+    m_registeredDocsModel->setDocEntries(entries);
+
+    if (m_registereredDocsFilterModel->rowCount()) {
+        const QModelIndex first = m_registereredDocsFilterModel->index(0, 0);
+        m_ui.registeredDocsListView->selectionModel()->setCurrentIndex(first,
+                                                                       QItemSelectionModel::ClearAndSelect);
     }
 }
 
