@@ -1,31 +1,26 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the Qt Designer of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL21$
+** $QT_BEGIN_LICENSE:GPL-EXCEPT$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** As a special exception, The Qt Company gives you certain additional
-** rights. These rights are described in The Qt Company LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3 as published by the Free Software
+** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -184,10 +179,8 @@ FormWindow::Selection::~Selection()
 void FormWindow::Selection::clear()
 {
     if (!m_usedSelections.empty()) {
-        const SelectionHash::iterator mend = m_usedSelections.end();
-        for (SelectionHash::iterator it = m_usedSelections.begin(); it != mend; ++it) {
+        for (auto it = m_usedSelections.begin(), mend = m_usedSelections.end(); it != mend; ++it)
             it.value()->setWidget(0);
-        }
         m_usedSelections.clear();
     }
 }
@@ -208,8 +201,7 @@ WidgetSelection *FormWindow::Selection::addWidget(FormWindow* fw, QWidget *w)
         return rc;
     }
     // find a free one in the pool
-    const SelectionPool::iterator pend = m_selectionPool.end();
-    for (SelectionPool::iterator it = m_selectionPool.begin(); it != pend; ++it) {
+    for (auto it = m_selectionPool.constBegin(), pend = m_selectionPool.constEnd(); it != pend; ++it) {
         if (! (*it)->isUsed()) {
             rc = *it;
             break;
@@ -249,10 +241,8 @@ void FormWindow::Selection::repaintSelection(QWidget *w)
 
 void FormWindow::Selection::repaintSelection()
 {
-    const SelectionHash::iterator mend = m_usedSelections.end();
-    for (SelectionHash::iterator it = m_usedSelections.begin(); it != mend; ++it) {
+    for (auto it = m_usedSelections.begin(), mend = m_usedSelections.end(); it != mend; ++it)
         it.value()->update();
-    }
 }
 
 bool FormWindow::Selection::isWidgetSelected(QWidget *w) const{
@@ -266,8 +256,7 @@ QWidgetList FormWindow::Selection::selectedWidgets() const
 
 void FormWindow::Selection::raiseList(const QWidgetList& l)
 {
-    const SelectionHash::iterator mend = m_usedSelections.end();
-    for (SelectionHash::iterator it = m_usedSelections.begin(); it != mend; ++it) {
+    for (auto it = m_usedSelections.constBegin(), mend = m_usedSelections.constEnd(); it != mend; ++it) {
         WidgetSelection *w = it.value();
         if (l.contains(w->widget()))
             w->show();
@@ -403,19 +392,23 @@ void FormWindow::init()
     m_defaultMargin = INT_MIN;
     m_defaultSpacing = INT_MIN;
 
-    connect(m_widgetStack, SIGNAL(currentToolChanged(int)), this, SIGNAL(toolChanged(int)));
+    connect(m_widgetStack, &FormWindowWidgetStack::currentToolChanged,
+            this, &QDesignerFormWindowInterface::toolChanged);
 
     m_selectionChangedTimer = new QTimer(this);
     m_selectionChangedTimer->setSingleShot(true);
-    connect(m_selectionChangedTimer, SIGNAL(timeout()), this, SLOT(selectionChangedTimerDone()));
+    connect(m_selectionChangedTimer, &QTimer::timeout, this,
+            &FormWindow::selectionChangedTimerDone);
 
     m_checkSelectionTimer = new QTimer(this);
     m_checkSelectionTimer->setSingleShot(true);
-    connect(m_checkSelectionTimer, SIGNAL(timeout()), this, SLOT(checkSelectionNow()));
+    connect(m_checkSelectionTimer, &QTimer::timeout,
+            this, &FormWindow::checkSelectionNow);
 
     m_geometryChangedTimer = new QTimer(this);
     m_geometryChangedTimer->setSingleShot(true);
-    connect(m_geometryChangedTimer, SIGNAL(timeout()), this, SIGNAL(geometryChanged()));
+    connect(m_geometryChangedTimer, &QTimer::timeout,
+            this, &QDesignerFormWindowInterface::geometryChanged);
 
     m_rubberBand = 0;
 
@@ -424,8 +417,10 @@ void FormWindow::init()
     m_mainContainer = 0;
     m_currentWidget = 0;
 
-    connect(&m_undoStack, SIGNAL(changed()), this, SIGNAL(changed()));
-    connect(&m_undoStack, SIGNAL(changed()), this, SLOT(checkSelection()));
+    connect(&m_undoStack, &QDesignerUndoStack::changed,
+            this, &QDesignerFormWindowInterface::changed);
+    connect(&m_undoStack, &QDesignerUndoStack::changed,
+            this, &FormWindow::checkSelection);
 
     core()->metaDataBase()->add(this);
 
@@ -434,7 +429,7 @@ void FormWindow::init()
     QAction *a = new QAction(this);
     a->setText(tr("Edit contents"));
     a->setShortcut(tr("F2"));
-    connect(a, SIGNAL(triggered()), this, SLOT(editContents()));
+    connect(a, &QAction::triggered, this, &FormWindow::editContents);
     addAction(a);
 }
 
@@ -531,7 +526,7 @@ static inline unsigned mouseFlags(Qt::KeyboardModifiers mod)
     case Qt::ShiftModifier:
         return CycleParentModifier;
         break;
-#ifdef Q_OS_MAC
+#ifdef Q_OS_MACOS
     case Qt::AltModifier: // "Alt" or "option" key on Mac means copy
         return CopyDragModifier;
 #endif
@@ -1498,8 +1493,8 @@ public:
     void init(QWidgetList &l, const ArrowKeyOperation &op);
 
 protected:
-    virtual PropertyHelper *createPropertyHelper(QObject *o, SpecialProperty sp,
-                                                 QDesignerPropertySheetExtension *s, int i) const
+    PropertyHelper *createPropertyHelper(QObject *o, SpecialProperty sp,
+                                         QDesignerPropertySheetExtension *s, int i) const Q_DECL_OVERRIDE
         { return new ArrowKeyPropertyHelper(o, sp, s, i); }
     QVariant mergeValue(const QVariant &newValue) Q_DECL_OVERRIDE;
 };
@@ -1551,6 +1546,8 @@ void FormWindow::handleArrowKeyEvent(int key, Qt::KeyboardModifiers modifiers)
             selection.append(w);
     }
 
+    simplifySelection(&selection);
+
     if (selection.isEmpty())
         return;
 
@@ -2182,8 +2179,6 @@ void FormWindow::layoutContainer(QWidget *w, int type)
     w = core()->widgetFactory()->containerOfWidget(w);
 
     const QObjectList l = w->children();
-    if (l.isEmpty())
-        return;
     // find managed widget children
     QWidgetList widgets;
     const QObjectList::const_iterator ocend = l.constEnd();
@@ -2194,6 +2189,9 @@ void FormWindow::layoutContainer(QWidget *w, int type)
                 widgets.append(widget);
         }
 
+    if (widgets.isEmpty()) // QTBUG-50563, observed when using hand-edited forms.
+        return;
+
     LayoutCommand *cmd = new LayoutCommand(this);
     cmd->init(mainContainer(), widgets, static_cast<LayoutInfo::Type>(type), w);
     clearSelection(false);
@@ -2252,7 +2250,7 @@ QAction *FormWindow::createSelectAncestorSubMenu(QWidget *w)
     // Create a submenu listing the managed, unselected parents
     QMenu *menu = new QMenu;
     QActionGroup *ag = new QActionGroup(menu);
-    QObject::connect(ag, SIGNAL(triggered(QAction*)), this, SLOT(slotSelectWidget(QAction*)));
+    QObject::connect(ag, &QActionGroup::triggered, this, &FormWindow::slotSelectWidget);
     const int size = parents.size();
     for (int i = 0; i < size; i++) {
         QWidget *w = parents.at(i);
