@@ -1,31 +1,26 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the Qt Designer of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL21$
+** $QT_BEGIN_LICENSE:GPL-EXCEPT$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** As a special exception, The Qt Company gives you certain additional
-** rights. These rights are described in The Qt Company LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3 as published by the Free Software
+** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -68,8 +63,8 @@ PaletteEditor::PaletteEditor(QDesignerFormEditorInterface *core, QWidget *parent
     ColorDelegate *delegate = new ColorDelegate(core, this);
     ui.paletteView->setItemDelegate(delegate);
     ui.paletteView->setEditTriggers(QAbstractItemView::AllEditTriggers);
-    connect(m_paletteModel, SIGNAL(paletteChanged(QPalette)),
-                this, SLOT(paletteChanged(QPalette)));
+    connect(m_paletteModel, &PaletteModel::paletteChanged,
+                this, &PaletteEditor::paletteChanged);
     ui.paletteView->setSelectionBehavior(QAbstractItemView::SelectRows);
     ui.paletteView->setDragEnabled(true);
     ui.paletteView->setDropIndicatorShown(true);
@@ -416,7 +411,7 @@ BrushEditor::BrushEditor(QDesignerFormEditorInterface *core, QWidget *parent) :
     QLayout *layout = new QHBoxLayout(this);
     layout->setMargin(0);
     layout->addWidget(m_button);
-    connect(m_button, SIGNAL(colorChanged(QColor)), this, SLOT(brushChanged()));
+    connect(m_button, &QtColorButton::colorChanged, this, &BrushEditor::brushChanged);
     setFocusProxy(m_button);
 }
 
@@ -464,7 +459,7 @@ RoleEditor::RoleEditor(QWidget *parent) :
     button->setIconSize(QSize(8,8));
     button->setSizePolicy(QSizePolicy(QSizePolicy::Fixed, QSizePolicy::MinimumExpanding));
     layout->addWidget(button);
-    connect(button, SIGNAL(clicked()), this, SLOT(emitResetProperty()));
+    connect(button, &QAbstractButton::clicked, this, &RoleEditor::emitResetProperty);
 }
 
 void RoleEditor::setLabel(const QString &label)
@@ -506,13 +501,16 @@ QWidget *ColorDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem
     QWidget *ed = 0;
     if (index.column() == 0) {
         RoleEditor *editor = new RoleEditor(parent);
-        connect(editor, SIGNAL(changed(QWidget*)), this, SIGNAL(commitData(QWidget*)));
+        connect(editor, &RoleEditor::changed, this, &ColorDelegate::commitData);
         //editor->setFocusPolicy(Qt::NoFocus);
         //editor->installEventFilter(const_cast<ColorDelegate *>(this));
         ed = editor;
     } else {
+        typedef void (BrushEditor::*BrushEditorWidgetSignal)(QWidget *);
+
         BrushEditor *editor = new BrushEditor(m_core, parent);
-        connect(editor, SIGNAL(changed(QWidget*)), this, SIGNAL(commitData(QWidget*)));
+        connect(editor, static_cast<BrushEditorWidgetSignal>(&BrushEditor::changed),
+                this, &ColorDelegate::commitData);
         editor->setFocusPolicy(Qt::NoFocus);
         editor->installEventFilter(const_cast<ColorDelegate *>(this));
         ed = editor;
