@@ -1,31 +1,26 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the Qt Designer of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL21$
+** $QT_BEGIN_LICENSE:GPL-EXCEPT$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** As a special exception, The Qt Company gives you certain additional
-** rights. These rights are described in The Qt Company LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3 as published by the Free Software
+** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -61,8 +56,8 @@ TreeWidgetEditor::TreeWidgetEditor(QDesignerFormWindowInterface *form, QDialog *
     ui.setupUi(dialog);
 
     injectPropertyBrowser(ui.itemsTab, ui.widget);
-    connect(ui.showPropertiesButton, SIGNAL(clicked()),
-            this, SLOT(togglePropertyBrowser()));
+    connect(ui.showPropertiesButton, &QAbstractButton::clicked,
+            this, &TreeWidgetEditor::togglePropertyBrowser);
     setPropertyBrowserVisible(false);
 
     ui.tabWidget->insertTab(0, m_columnEditor, tr("&Columns"));
@@ -79,32 +74,32 @@ TreeWidgetEditor::TreeWidgetEditor(QDesignerFormWindowInterface *form, QDialog *
 
     ui.treeWidget->header()->setSectionsMovable(false);
 
-    connect(ui.newItemButton, SIGNAL(clicked()), this, SLOT(on_newItemButton_clicked()));
-    connect(ui.newSubItemButton, SIGNAL(clicked()), this, SLOT(on_newSubItemButton_clicked()));
-    connect(ui.moveItemUpButton, SIGNAL(clicked()), this, SLOT(on_moveItemUpButton_clicked()));
-    connect(ui.moveItemDownButton, SIGNAL(clicked()), this, SLOT(on_moveItemDownButton_clicked()));
-    connect(ui.moveItemRightButton, SIGNAL(clicked()), this, SLOT(on_moveItemRightButton_clicked()));
-    connect(ui.moveItemLeftButton, SIGNAL(clicked()), this, SLOT(on_moveItemLeftButton_clicked()));
-    connect(ui.deleteItemButton, SIGNAL(clicked()), this, SLOT(on_deleteItemButton_clicked()));
-    connect(ui.treeWidget, SIGNAL(currentItemChanged(QTreeWidgetItem*,QTreeWidgetItem*)),
-            this, SLOT(on_treeWidget_currentItemChanged()));
-    connect(ui.treeWidget, SIGNAL(itemChanged(QTreeWidgetItem*,int)),
-            this, SLOT(on_treeWidget_itemChanged(QTreeWidgetItem*,int)));
+    connect(ui.newItemButton, &QAbstractButton::clicked, this, &TreeWidgetEditor::on_newItemButton_clicked);
+    connect(ui.newSubItemButton, &QAbstractButton::clicked, this, &TreeWidgetEditor::on_newSubItemButton_clicked);
+    connect(ui.moveItemUpButton, &QAbstractButton::clicked, this, &TreeWidgetEditor::on_moveItemUpButton_clicked);
+    connect(ui.moveItemDownButton, &QAbstractButton::clicked, this, &TreeWidgetEditor::on_moveItemDownButton_clicked);
+    connect(ui.moveItemRightButton, &QAbstractButton::clicked, this, &TreeWidgetEditor::on_moveItemRightButton_clicked);
+    connect(ui.moveItemLeftButton, &QAbstractButton::clicked, this, &TreeWidgetEditor::on_moveItemLeftButton_clicked);
+    connect(ui.deleteItemButton, &QAbstractButton::clicked, this, &TreeWidgetEditor::on_deleteItemButton_clicked);
+    connect(ui.treeWidget, &QTreeWidget::currentItemChanged,
+            this, &TreeWidgetEditor::on_treeWidget_currentItemChanged);
+    connect(ui.treeWidget, &QTreeWidget::itemChanged,
+            this, &TreeWidgetEditor::on_treeWidget_itemChanged);
 
-    connect(m_columnEditor, SIGNAL(indexChanged(int)),
-            this, SLOT(on_columnEditor_indexChanged(int)));
-    connect(m_columnEditor, SIGNAL(itemChanged(int,int,QVariant)),
-            this, SLOT(on_columnEditor_itemChanged(int,int,QVariant)));
-    connect(m_columnEditor, SIGNAL(itemInserted(int)),
-            this, SLOT(on_columnEditor_itemInserted(int)));
-    connect(m_columnEditor, SIGNAL(itemDeleted(int)),
-            this, SLOT(on_columnEditor_itemDeleted(int)));
-    connect(m_columnEditor, SIGNAL(itemMovedUp(int)),
-            this, SLOT(on_columnEditor_itemMovedUp(int)));
-    connect(m_columnEditor, SIGNAL(itemMovedDown(int)),
-            this, SLOT(on_columnEditor_itemMovedDown(int)));
+    connect(m_columnEditor, &ItemListEditor::indexChanged,
+            this, &TreeWidgetEditor::on_columnEditor_indexChanged);
+    connect(m_columnEditor, &ItemListEditor::itemChanged,
+            this, &TreeWidgetEditor::on_columnEditor_itemChanged);
+    connect(m_columnEditor, &ItemListEditor::itemInserted,
+            this, &TreeWidgetEditor::on_columnEditor_itemInserted);
+    connect(m_columnEditor, &ItemListEditor::itemDeleted,
+            this, &TreeWidgetEditor::on_columnEditor_itemDeleted);
+    connect(m_columnEditor, &ItemListEditor::itemMovedUp,
+            this, &TreeWidgetEditor::on_columnEditor_itemMovedUp);
+    connect(m_columnEditor, &ItemListEditor::itemMovedDown,
+            this, &TreeWidgetEditor::on_columnEditor_itemMovedDown);
 
-    connect(iconCache(), SIGNAL(reloaded()), this, SLOT(cacheReloaded()));
+    connect(iconCache(), &DesignerIconCache::reloaded, this, &TreeWidgetEditor::cacheReloaded);
 }
 
 static AbstractItemEditor::PropertyDefinition treeHeaderPropList[] = {
