@@ -1,31 +1,26 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the Qt Designer of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL21$
+** $QT_BEGIN_LICENSE:GPL-EXCEPT$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** As a special exception, The Qt Company gives you certain additional
-** rights. These rights are described in The Qt Company LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3 as published by the Free Software
+** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -87,18 +82,18 @@ CodeDialog::CodeDialog(QWidget *parent) :
 
     const QIcon saveIcon = createIconSet(QStringLiteral("filesave.png"));
     QAction *saveAction = toolBar->addAction(saveIcon, tr("Save..."));
-    connect(saveAction, SIGNAL(triggered()), this, SLOT(slotSaveAs()));
+    connect(saveAction, &QAction::triggered, this, &CodeDialog::slotSaveAs);
 
 #ifndef QT_NO_CLIPBOARD
     const QIcon copyIcon = createIconSet(QStringLiteral("editcopy.png"));
     QAction *copyAction = toolBar->addAction(copyIcon, tr("Copy All"));
-    connect(copyAction, SIGNAL(triggered()), this, SLOT(copyAll()));
+    connect(copyAction, &QAction::triggered, this, &CodeDialog::copyAll);
 #endif
 
     QAction *findAction = toolBar->addAction(
             TextEditFindWidget::findIconSet(),
             tr("&Find in Text..."),
-            m_impl->m_findWidget, SLOT(activate()));
+            m_impl->m_findWidget, &AbstractFindWidget::activate);
     findAction->setShortcut(QKeySequence::Find);
 
     vBoxLayout->addWidget(toolBar);
@@ -116,7 +111,7 @@ CodeDialog::CodeDialog(QWidget *parent) :
 
     // Button box
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close);
-    connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
+    connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
 
     // Disable auto default
     QPushButton *closeButton = buttonBox->button(QDialogButtonBox::Close);
