@@ -1,31 +1,26 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the Qt Designer of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL21$
+** $QT_BEGIN_LICENSE:GPL-EXCEPT$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** As a special exception, The Qt Company gives you certain additional
-** rights. These rights are described in The Qt Company LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3 as published by the Free Software
+** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -177,11 +172,9 @@ namespace qdesigner_internal
 
     QStringList DesignerMetaFlags::flags(int ivalue) const
     {
-        typedef MetaEnum<uint>::KeyToValueMap::const_iterator KeyToValueMapIterator;
         QStringList rc;
         const uint v = static_cast<uint>(ivalue);
-        const KeyToValueMapIterator cend = keyToValueMap().constEnd();
-        for (KeyToValueMapIterator it = keyToValueMap().constBegin();it != cend; ++it )  {
+        for (auto it = keyToValueMap().constBegin(), cend = keyToValueMap().constEnd(); it != cend; ++it )  {
             const uint itemValue = it.value();
             // Check for equality first as flag values can be 0 or -1, too. Takes preference over a bitwise flag
             if (v == itemValue) {
@@ -229,8 +222,7 @@ namespace qdesigner_internal
         uint flags = 0;
         bool valueOk = true;
         QStringList keys = s.split(QString(QLatin1Char('|')));
-        const QStringList::iterator cend = keys.end();
-        for (QStringList::iterator it = keys.begin(); it != cend; ++it) {
+        for (auto it = keys.constBegin(), cend = keys.constEnd(); it != cend; ++it) {
             const uint flagValue = keyToValue(*it, &valueOk);
             if (!valueOk) {
                 flags = 0;
@@ -422,9 +414,7 @@ namespace qdesigner_internal
 
     QIcon DesignerIconCache::icon(const PropertySheetIconValue &value) const
     {
-        typedef PropertySheetIconValue::ModeStateToPixmapMap::const_iterator ModeStateToPixmapMapConstIt;
-
-        QMap<PropertySheetIconValue, QIcon>::const_iterator it = m_cache.constFind(value);
+        const auto it = m_cache.constFind(value);
         if (it != m_cache.constEnd())
             return it.value();
 
@@ -440,9 +430,8 @@ namespace qdesigner_internal
 
         QIcon icon;
         const PropertySheetIconValue::ModeStateToPixmapMap &paths = value.paths();
-        const ModeStateToPixmapMapConstIt cend = paths.constEnd();
-        for (ModeStateToPixmapMapConstIt it = paths.constBegin(); it != cend; ++it) {
-            const QPair<QIcon::Mode, QIcon::State> pair = it.key();
+        for (auto it = paths.constBegin(), cend = paths.constEnd(); it != cend; ++it) {
+            const auto pair = it.key();
             icon.addFile(it.value().path(), QSize(), pair.first, pair.second);
         }
         m_cache.insert(value, icon);
@@ -619,11 +608,8 @@ namespace qdesigner_internal
 
     uint PropertySheetIconValue::mask() const
     {
-        typedef ModeStateToPixmapMap::const_iterator ModeStateToPixmapMapConstIt;
-
         uint flags = 0;
-        const ModeStateToPixmapMapConstIt cend = m_data->m_paths.constEnd();
-        for (ModeStateToPixmapMapConstIt it = m_data->m_paths.constBegin(); it != cend; ++it)
+        for (auto it = m_data->m_paths.constBegin(), cend = m_data->m_paths.constEnd(); it != cend; ++it)
             flags |= iconStateToSubPropertyFlag(it.key().first, it.key().second);
         if (!m_data->m_theme.isEmpty())
             flags |= ThemeIconMask;
@@ -680,14 +666,11 @@ namespace qdesigner_internal
 
     QDESIGNER_SHARED_EXPORT QDebug operator<<(QDebug d, const PropertySheetIconValue &p)
     {
-        typedef PropertySheetIconValue::ModeStateToPixmapMap::const_iterator ModeStateToPixmapMapConstIt;
-
         QDebug nospace = d.nospace();
         nospace << "PropertySheetIconValue theme='" << p.theme() << "' ";
 
         const PropertySheetIconValue::ModeStateToPixmapMap &paths = p.paths();
-        const ModeStateToPixmapMapConstIt cend = paths.constEnd();
-        for (ModeStateToPixmapMapConstIt it = paths.constBegin(); it != cend; ++it)
+        for (auto it = paths.constBegin(), cend = paths.constEnd(); it != cend; ++it)
             nospace << " mode=" << it.key().first << ",state=" << it.key().second
                        << ",'" << it.value().path() << '\'';
         nospace << " mask=0x" << QString::number(p.mask(), 16);
