@@ -1,31 +1,26 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the Qt Designer of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL21$
+** $QT_BEGIN_LICENSE:GPL-EXCEPT$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** As a special exception, The Qt Company gives you certain additional
-** rights. These rights are described in The Qt Company LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3 as published by the Free Software
+** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -474,8 +469,8 @@ QRect LayoutHelper::itemInfo(QLayout *lt, const QWidget *widget) const
         void pushState(const QDesignerFormEditorInterface *, const QWidget *) Q_DECL_OVERRIDE;
         void popState(const QDesignerFormEditorInterface *, QWidget *) Q_DECL_OVERRIDE;
 
-        virtual bool canSimplify(const QDesignerFormEditorInterface *, const QWidget *, const QRect &) const { return  false; }
-        virtual void simplify(const QDesignerFormEditorInterface *, QWidget *, const QRect &) {}
+        bool canSimplify(const QDesignerFormEditorInterface *, const QWidget *, const QRect &) const Q_DECL_OVERRIDE { return  false; }
+        void simplify(const QDesignerFormEditorInterface *, QWidget *, const QRect &) Q_DECL_OVERRIDE {}
 
         // Helper for restoring layout states
         typedef QVector <QLayoutItem *> LayoutItemVector;
@@ -762,8 +757,7 @@ QRect LayoutHelper::itemInfo(QLayout *lt, const QWidget *widget) const
     void GridLayoutState::insertRow(int row)
     {
         rowCount++;
-        const WidgetItemMap::iterator iend = widgetItemMap.end();
-        for (WidgetItemMap::iterator it = widgetItemMap.begin(); it != iend; ++it) {
+        for (auto it = widgetItemMap.begin(), iend = widgetItemMap.end(); it != iend; ++it) {
             const int topRow = it.value().y();
             if (topRow >= row) {
                 it.value().translate(0, 1);
@@ -778,8 +772,7 @@ QRect LayoutHelper::itemInfo(QLayout *lt, const QWidget *widget) const
     void GridLayoutState::insertColumn(int column)
     {
         colCount++;
-        const WidgetItemMap::iterator iend = widgetItemMap.end();
-        for (WidgetItemMap::iterator it = widgetItemMap.begin(); it != iend; ++it) {
+        for (auto it = widgetItemMap.begin(), iend = widgetItemMap.end(); it != iend; ++it) {
             const int leftColumn = it.value().x();
             if (leftColumn >= column) {
                 it.value().translate(1, 0);
@@ -843,8 +836,7 @@ QRect LayoutHelper::itemInfo(QLayout *lt, const QWidget *widget) const
 
     void GridLayoutState::removeFreeRow(int removeRow)
     {
-        const WidgetItemMap::iterator iend = widgetItemMap.end();
-        for (WidgetItemMap::iterator it = widgetItemMap.begin(); it != iend; ++it) {
+        for (auto it = widgetItemMap.begin(), iend = widgetItemMap.end(); it != iend; ++it) {
             const int r = it.value().y();
             Q_ASSERT(r != removeRow); // Free rows only
             if (r < removeRow) { // Does the item span it? - shrink it
@@ -863,8 +855,7 @@ QRect LayoutHelper::itemInfo(QLayout *lt, const QWidget *widget) const
 
     void GridLayoutState::removeFreeColumn(int removeColumn)
     {
-        const WidgetItemMap::iterator iend = widgetItemMap.end();
-        for (WidgetItemMap::iterator it = widgetItemMap.begin(); it != iend; ++it) {
+        for (auto it = widgetItemMap.begin(), iend = widgetItemMap.end(); it != iend; ++it) {
             const int c = it.value().x();
             Q_ASSERT(c != removeColumn); // Free columns only
             if (c < removeColumn) { // Does the item span it? - shrink it
@@ -1567,11 +1558,11 @@ public:
 
     void insertWidget(QWidget *widget, const QPair<int, int> &cell) Q_DECL_OVERRIDE;
     void removeWidget(QWidget *widget) Q_DECL_OVERRIDE;
-    virtual void simplify() {}
-    virtual void insertRow(int /*row*/) {}
-    virtual void insertColumn(int /*column*/) {}
+    void simplify() Q_DECL_OVERRIDE {}
+    void insertRow(int /*row*/) Q_DECL_OVERRIDE {}
+    void insertColumn(int /*column*/) Q_DECL_OVERRIDE {}
 
-    virtual int findItemAt(int /*at_row*/, int /*at_column*/) const {    return -1; }
+    int findItemAt(int /*at_row*/, int /*at_column*/) const Q_DECL_OVERRIDE {    return -1; }
     using QLayoutSupport::findItemAt;
 
 private:
@@ -1697,8 +1688,8 @@ public:
     GridLikeLayoutSupportBase(QDesignerFormWindowInterface *formWindow, QWidget *widget, LayoutHelper *helper, QObject *parent = 0) :
         QLayoutSupport(formWindow, widget, helper, parent) {}
 
-    void insertWidget(QWidget *widget, const QPair<int, int> &cell);
-    virtual void removeWidget(QWidget *widget) { helper()->removeWidget(layout(), widget); }
+    void insertWidget(QWidget *widget, const QPair<int, int> &cell) Q_DECL_OVERRIDE;
+    void removeWidget(QWidget *widget) Q_DECL_OVERRIDE { helper()->removeWidget(layout(), widget); }
     int findItemAt(int row, int column) const Q_DECL_OVERRIDE;
     using QLayoutSupport::findItemAt;
 
@@ -1711,7 +1702,7 @@ private:
 
     void setCurrentCellFromIndicatorOnEmptyCell(int index) Q_DECL_OVERRIDE;
     void setCurrentCellFromIndicator(Qt::Orientation indicatorOrientation, int index, int increment) Q_DECL_OVERRIDE;
-    virtual bool supportsIndicatorOrientation(Qt::Orientation) const { return true; }
+    bool supportsIndicatorOrientation(Qt::Orientation) const Q_DECL_OVERRIDE { return true; }
 
     QRect extendedGeometry(int index) const Q_DECL_OVERRIDE;
 
@@ -1811,7 +1802,7 @@ public:
 
     QGridLayoutSupport(QDesignerFormWindowInterface *formWindow, QWidget *widget, QObject *parent = 0);
 
-    virtual void simplify();
+    void simplify() Q_DECL_OVERRIDE;
     void insertRow(int row) Q_DECL_OVERRIDE;
     void insertColumn(int column) Q_DECL_OVERRIDE;
 
@@ -1858,9 +1849,9 @@ class QFormLayoutSupport: public GridLikeLayoutSupportBase<QFormLayout>
 public:
     QFormLayoutSupport(QDesignerFormWindowInterface *formWindow, QWidget *widget, QObject *parent = 0);
 
-    virtual void simplify() {}
-    virtual void insertRow(int /*row*/) {}
-    virtual void insertColumn(int /*column*/) {}
+    void simplify() Q_DECL_OVERRIDE {}
+    void insertRow(int /*row*/) Q_DECL_OVERRIDE {}
+    void insertColumn(int /*column*/) Q_DECL_OVERRIDE {}
 
 private:
     void checkCellForInsertion(int * row, int *col) const Q_DECL_OVERRIDE;
