@@ -1,31 +1,26 @@
 /****************************************************************************
 **
-** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the Qt Designer of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL21$
+** $QT_BEGIN_LICENSE:GPL-EXCEPT$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia. For licensing terms and
-** conditions see http://qt.digia.com/licensing. For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Digia gives you certain additional
-** rights. These rights are described in the Digia Qt LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3 as published by the Free Software
+** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -290,13 +285,11 @@ public:
     // helpers
     QtQrcFile *qrcFileOf(const QString &path) const;
     QtQrcFile *qrcFileOf(QtResourcePrefix *resourcePrefix) const;
-    QtQrcFile *qrcFileOf(QtResourceFile *resourceFile) const;
     QtResourcePrefix *resourcePrefixOf(QtResourceFile *resourceFile) const;
 
     QtQrcFile *importQrcFile(const QtQrcFileData &qrcFileData, QtQrcFile *beforeQrcFile = 0);
     void exportQrcFile(QtQrcFile *qrcFile, QtQrcFileData *qrcFileData) const;
 
-    QList<QtResourceFile *> resourceFilesOf(const QString &resourceFullPath) const;
     QIcon icon(const QString &resourceFullPath) const;
     bool exists(const QString &resourceFullPath) const;
     bool exists(QtQrcFile *qrcFile) const;
@@ -383,11 +376,6 @@ QtQrcFile *QtQrcManager::qrcFileOf(QtResourcePrefix *resourcePrefix) const
     return m_prefixToQrc.value(resourcePrefix);
 }
 
-QtQrcFile *QtQrcManager::qrcFileOf(QtResourceFile *resourceFile) const
-{
-    return qrcFileOf(resourcePrefixOf(resourceFile));
-}
-
 QtResourcePrefix *QtQrcManager::resourcePrefixOf(QtResourceFile *resourceFile) const
 {
     return m_fileToPrefix.value(resourceFile);
@@ -452,11 +440,6 @@ void QtQrcManager::exportQrcFile(QtQrcFile *qrcFile, QtQrcFileData *qrcFileData)
     data.resourceList = resourceList;
 }
 
-QList<QtResourceFile *> QtQrcManager::resourceFilesOf(const QString &resourcePath) const
-{
-    return m_fullPathToResourceFiles.value(resourcePath);
-}
-
 QIcon QtQrcManager::icon(const QString &resourceFullPath) const
 {
     return m_fullPathToIcon.value(resourceFullPath);
