@@ -1,31 +1,26 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the Qt Designer of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL21$
+** $QT_BEGIN_LICENSE:GPL-EXCEPT$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** As a special exception, The Qt Company gives you certain additional
-** rights. These rights are described in The Qt Company LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3 as published by the Free Software
+** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -339,7 +334,7 @@ public:
         return ParentClass::createActionGroup(parent, name);
     }
 
-    virtual QWidget *createWidget(const QString &className, QWidget *parent, const QString &name)
+    QWidget *createWidget(const QString &className, QWidget *parent, const QString &name) Q_DECL_OVERRIDE
     {
         if (QWidget *widget = loader->createWidget(className, parent, name)) {
             widget->setObjectName(name);
@@ -349,7 +344,7 @@ public:
         return 0;
     }
 
-    virtual QLayout *createLayout(const QString &className, QObject *parent, const QString &name)
+    QLayout *createLayout(const QString &className, QObject *parent, const QString &name) Q_DECL_OVERRIDE
     {
         if (QLayout *layout = loader->createLayout(className, parent, name)) {
             layout->setObjectName(name);
@@ -359,7 +354,7 @@ public:
         return 0;
     }
 
-    virtual QActionGroup *createActionGroup(QObject *parent, const QString &name)
+    QActionGroup *createActionGroup(QObject *parent, const QString &name) Q_DECL_OVERRIDE
     {
         if (QActionGroup *actionGroup = loader->createActionGroup(parent, name)) {
             actionGroup->setObjectName(name);
@@ -369,7 +364,7 @@ public:
         return 0;
     }
 
-    virtual QAction *createAction(QObject *parent, const QString &name)
+    QAction *createAction(QObject *parent, const QString &name)  Q_DECL_OVERRIDE
     {
         if (QAction *action = loader->createAction(parent, name)) {
             action->setObjectName(name);
