@@ -1,32 +1,27 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd.
-** Copyright (C) 2012 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com, author Marc Mutz <marc.mutz@kdab.com>
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2016 The Qt Company Ltd.
+** Copyright (C) 2016 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com, author Marc Mutz <marc.mutz@kdab.com>
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the Qt Linguist of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL21$
+** $QT_BEGIN_LICENSE:GPL-EXCEPT$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** As a special exception, The Qt Company gives you certain additional
-** rights. These rights are described in The Qt Company LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3 as published by the Free Software
+** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -49,7 +44,6 @@
 #include <QtCore/QStringList>
 #include <QtCore/QTranslator>
 #include <QtCore/QLibraryInfo>
-#include <QtCore/QXmlStreamReader>
 
 #include <iostream>
 
@@ -396,73 +390,6 @@ public:
 
 static EvalHandler evalHandler;
 
-static bool isSupportedExtension(const QString &ext)
-{
-    return ext == QLatin1String("qml")
-        || ext == QLatin1String("js") || ext == QLatin1String("qs")
-        || ext == QLatin1String("ui") || ext == QLatin1String("jui");
-}
-
-static QStringList getResources(const QString &resourceFile, QMakeVfs *vfs)
-{
-    Q_ASSERT(vfs);
-    if (!vfs->exists(resourceFile))
-        return QStringList();
-    QString content;
-    QString errStr;
-    if (!vfs->readFile(resourceFile, &content, &errStr)) {
-        printErr(LU::tr("lupdate error: Can not read %1: %2\n").arg(resourceFile, errStr));
-        return QStringList();
-    }
-    QStringList fileList;
-    QString dirPath = QFileInfo(resourceFile).path();
-    QXmlStreamReader reader(content);
-    bool isFileTag = false;
-    QStringList tagStack;
-    tagStack << QLatin1String("RCC") << QLatin1String("qresource") << QLatin1String("file");
-    int curDepth = 0;
-    while (!reader.atEnd()) {
-        QXmlStreamReader::TokenType t = reader.readNext();
-        switch (t) {
-        case QXmlStreamReader::StartElement:
-            if (curDepth >= tagStack.count() || reader.name() != tagStack.at(curDepth)) {
-                printErr(LU::tr("unexpected <%1> tag\n").arg(reader.name().toString()));
-                continue;
-            }
-            if (++curDepth == tagStack.count())
-                isFileTag = true;
-            break;
-
-        case QXmlStreamReader::EndElement:
-            isFileTag = false;
-            if (curDepth == 0 || reader.name() != tagStack.at(curDepth - 1)) {
-                printErr(LU::tr("unexpected closing <%1> tag\n").arg(reader.name().toString()));
-                continue;
-            }
-            --curDepth;
-            break;
-
-        case QXmlStreamReader::Characters:
-            if (isFileTag) {
-                QString fn = reader.text().toString();
-                if (!QFileInfo(fn).isAbsolute())
-                    fn = dirPath + QLatin1Char('/') + fn;
-                QFileInfo cfi(fn);
-                if (isSupportedExtension(cfi.suffix()))
-                    fileList << cfi.filePath();
-            }
-            break;
-
-        default:
-            break;
-        }
-    }
-    if (reader.error() != QXmlStreamReader::NoError)
-        printErr(LU::tr("lupdate error: %1:%2: %3\n")
-                 .arg(resourceFile, QString::number(reader.lineNumber()), reader.errorString()));
-    return fileList;
-}
-
 static QStringList getSources(const char *var, const char *vvar, const QStringList &baseVPaths,
                               const QString &projectDir, const ProFileEvaluator &visitor)
 {
@@ -473,7 +400,7 @@ static QStringList getSources(const char *var, const char *vvar, const QStringLi
 }
 
 static QStringList getSources(const ProFileEvaluator &visitor, const QString &projectDir,
-                              const QStringList &excludes, QMakeVfs *vfs)
+                              const QStringList &excludes)
 {
     QStringList baseVPaths;
     baseVPaths += visitor.absolutePathValues(QLatin1String("VPATH"), projectDir);
@@ -488,10 +415,6 @@ static QStringList getSources(const ProFileEvaluator &visitor, const QString &pr
 
     sourceFiles += getSources("FORMS", "VPATH_FORMS", baseVPaths, projectDir, visitor);
 
-    QStringList resourceFiles = getSources("RESOURCES", "VPATH_RESOURCES", baseVPaths, projectDir, visitor);
-    foreach (const QString &resource, resourceFiles)
-        sourceFiles += getResources(resource, vfs);
-
     QStringList installs = visitor.values(QLatin1String("INSTALLS"))
                          + visitor.values(QLatin1String("DEPLOYMENT"));
     installs.removeDuplicates();
@@ -517,8 +440,12 @@ static QStringList getSources(const ProFileEvaluator &visitor, const QString &pr
             while (iterator.hasNext()) {
                 iterator.next();
                 QFileInfo cfi = iterator.fileInfo();
-                if (isSupportedExtension(cfi.suffix()))
+                QString ext = cfi.suffix();
+                if (ext == QLatin1String("qml")
+                    || ext == QLatin1String("js") || ext == QLatin1String("qs")
+                    || ext == QLatin1String("ui") || ext == QLatin1String("jui")) {
                     sourceFiles << cfi.filePath();
+                }
             }
         }
     }
@@ -680,7 +607,7 @@ static void processProject(
         cd.m_sourceIsUtf16 = options & SourceIsUtf16;
         cd.m_includePath = visitor.absolutePathValues(QLatin1String("INCLUDEPATH"), proPath);
         cd.m_excludes = getExcludes(visitor, proPath);
-        QStringList sourceFiles = getSources(visitor, proPath, cd.m_excludes, vfs);
+        QStringList sourceFiles = getSources(visitor, proPath, cd.m_excludes);
         QSet<QString> sourceDirs;
         sourceDirs.insert(proPath + QLatin1Char('/'));
         foreach (const QString &sf, sourceFiles)
@@ -791,7 +718,7 @@ int main(int argc, char **argv)
 #endif // Q_OS_WIN32
 #endif
 
-    m_defaultExtensions = QLatin1String("java,jui,ui,c,c++,cc,cpp,cxx,ch,h,h++,hh,hpp,hxx,js,qs,qml,qrc");
+    m_defaultExtensions = QLatin1String("java,jui,ui,c,c++,cc,cpp,cxx,ch,h,h++,hh,hpp,hxx,js,qs,qml");
 
     QStringList args = app.arguments();
     QStringList tsFileNames;
@@ -801,7 +728,6 @@ int main(int argc, char **argv)
     QMultiHash<QString, QString> allCSources;
     QSet<QString> projectRoots;
     QStringList sourceFiles;
-    QStringList resourceFiles;
     QStringList includePath;
     QStringList alienFiles;
     QString targetLanguage;
@@ -1055,33 +981,25 @@ int main(int argc, char **argv)
                     int scanRootLen = dir.absolutePath().length();
                     foreach (const QFileInfo &fi, fileinfolist) {
                         QString fn = QDir::cleanPath(fi.absoluteFilePath());
-                        if (fn.endsWith(QLatin1String(".qrc"), Qt::CaseInsensitive)) {
-                            resourceFiles << fn;
-                        } else {
-                            sourceFiles << fn;
+                        sourceFiles << fn;
 
-                            if (!fn.endsWith(QLatin1String(".java"))
-                                    && !fn.endsWith(QLatin1String(".jui"))
-                                    && !fn.endsWith(QLatin1String(".ui"))
-                                    && !fn.endsWith(QLatin1String(".js"))
-                                    && !fn.endsWith(QLatin1String(".qs"))
-                                    && !fn.endsWith(QLatin1String(".qml"))) {
-                                int offset = 0;
-                                int depth = 0;
-                                do {
-                                    offset = fn.lastIndexOf(QLatin1Char('/'), offset - 1);
-                                    QString ffn = fn.mid(offset + 1);
-                                    allCSources.insert(ffn, fn);
-                                } while (++depth < 3 && offset > scanRootLen);
-                            }
+                        if (!fn.endsWith(QLatin1String(".java"))
+                            && !fn.endsWith(QLatin1String(".jui"))
+                            && !fn.endsWith(QLatin1String(".ui"))
+                            && !fn.endsWith(QLatin1String(".js"))
+                            && !fn.endsWith(QLatin1String(".qs"))
+                            && !fn.endsWith(QLatin1String(".qml"))) {
+                            int offset = 0;
+                            int depth = 0;
+                            do {
+                                offset = fn.lastIndexOf(QLatin1Char('/'), offset - 1);
+                                QString ffn = fn.mid(offset + 1);
+                                allCSources.insert(ffn, fn);
+                            } while (++depth < 3 && offset > scanRootLen);
                         }
                     }
                 } else {
-                    QString fn = QDir::cleanPath(fi.absoluteFilePath());
-                    if (fn.endsWith(QLatin1String(".qrc"), Qt::CaseInsensitive))
-                        resourceFiles << fn;
-                    else
-                        sourceFiles << fn;
+                    sourceFiles << QDir::cleanPath(fi.absoluteFilePath());;
                     projectRoots.insert(fi.absolutePath() + QLatin1Char('/'));
                 }
             }
@@ -1111,16 +1029,11 @@ int main(int argc, char **argv)
         cd.m_projectRoots = projectRoots;
         cd.m_includePath = includePath;
         cd.m_allCSources = allCSources;
-        if (!resourceFiles.isEmpty()) {
-            QMakeVfs vfs;
-            foreach (const QString &resource, resourceFiles)
-                sourceFiles << getResources(resource, &vfs);
-        }
         processSources(fetchedTor, sourceFiles, cd);
         updateTsFiles(fetchedTor, tsFileNames, alienFiles,
                       sourceLanguage, targetLanguage, options, &fail);
     } else {
-        if (!sourceFiles.isEmpty() || !resourceFiles.isEmpty() || !includePath.isEmpty()) {
+        if (!sourceFiles.isEmpty() || !includePath.isEmpty()) {
             printErr(LU::tr("lupdate error:"
                             " Both project and source files / include paths specified.\n"));
             return 1;
