@@ -1,31 +1,26 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the tools applications of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL21$
+** $QT_BEGIN_LICENSE:GPL-EXCEPT$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** As a special exception, The Qt Company gives you certain additional
-** rights. These rights are described in The Qt Company LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3 as published by the Free Software
+** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -54,6 +49,8 @@ static bool inMacroCommand_ = false;
 static bool parsingHeaderFile_ = false;
 QStringList CppCodeParser::exampleFiles;
 QStringList CppCodeParser::exampleDirs;
+QSet<QString> CppCodeParser::excludeDirs;
+QSet<QString> CppCodeParser::excludeFiles;
 CppCodeParser* CppCodeParser::cppParser_ = 0;
 
 /*!
@@ -78,7 +75,7 @@ CppCodeParser::~CppCodeParser()
 /*!
   The constructor initializes a map of special node types
   for identifying important nodes. And it initializes
-  some filters for identifying certain kinds of files.
+  some filters for identifying and excluding certain kinds of files.
  */
 void CppCodeParser::initializeParser(const Config &config)
 {
@@ -100,6 +97,10 @@ void CppCodeParser::initializeParser(const Config &config)
     QStringList exampleFilePatterns = config.getStringList(
                 CONFIG_EXAMPLES + Config::dot + CONFIG_FILEEXTENSIONS);
 
+    // Used for excluding dirs and files from the list of example files
+    excludeDirs = QSet<QString>::fromList(config.getCanonicalPathList(CONFIG_EXCLUDEDIRS));
+    excludeFiles = QSet<QString>::fromList(config.getCanonicalPathList(CONFIG_EXCLUDEFILES));
+
     if (!exampleFilePatterns.isEmpty())
         exampleNameFilter = exampleFilePatterns.join(' ');
     else
@@ -121,6 +122,8 @@ void CppCodeParser::initializeParser(const Config &config)
 void CppCodeParser::terminateParser()
 {
     nodeTypeMap.clear();
+    excludeDirs.clear();
+    excludeFiles.clear();
     CodeParser::terminateParser();
 }
 
@@ -967,7 +970,6 @@ void CppCodeParser::processOtherMetaCommand(const Doc& doc,
         else if (node->isQmlType() || node->isJsType()) {
             QmlTypeNode* qmlType = static_cast<QmlTypeNode*>(node);
             qmlType->setQmlBaseName(arg);
-            QmlTypeNode::addInheritedBy(arg,node);
         }
     }
     else if (command == COMMAND_QMLINSTANTIATES) {
@@ -1031,8 +1033,9 @@ void CppCodeParser::processOtherMetaCommand(const Doc& doc,
  */
 void CppCodeParser::processOtherMetaCommands(const Doc& doc, Node *node)
 {
-    const QSet<QString> metaCommands = doc.metaCommandsUsed();
-    QSet<QString>::ConstIterator cmd = metaCommands.constBegin();
+    QStringList metaCommands = doc.metaCommandsUsed().toList();
+    metaCommands.sort();
+    QStringList::ConstIterator cmd = metaCommands.constBegin();
     while (cmd != metaCommands.constEnd()) {
         ArgList args = doc.metaCommandArgs(*cmd);
         ArgList::ConstIterator arg = args.constBegin();
@@ -2643,9 +2646,9 @@ void CppCodeParser::createExampleFileNodes(DocumentNode *dn)
         sizeOfBoringPartOfName = sizeOfBoringPartOfName - 2;
     fullPath.truncate(fullPath.lastIndexOf('/'));
 
-    QStringList exampleFiles = Config::getFilesHere(fullPath,exampleNameFilter);
+    QStringList exampleFiles = Config::getFilesHere(fullPath, exampleNameFilter, Location(), excludeDirs, excludeFiles);
     QString imagesPath = fullPath + "/images";
-    QStringList imageFiles = Config::getFilesHere(imagesPath,exampleImageFilter);
+    QStringList imageFiles = Config::getFilesHere(imagesPath, exampleImageFilter, Location(), excludeDirs, excludeFiles);
     if (!exampleFiles.isEmpty()) {
         // move main.cpp and to the end, if it exists
         QString mainCpp;
