@@ -1,31 +1,26 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the tools applications of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL21$
+** $QT_BEGIN_LICENSE:GPL-EXCEPT$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** As a special exception, The Qt Company gives you certain additional
-** rights. These rights are described in The Qt Company LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3 as published by the Free Software
+** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -365,31 +360,26 @@ static void processQdocconfFile(const QString &fileName)
                                                      + Config::dot
                                                      + CONFIG_LANDINGPAGE));
 
-    QSet<QString> excludedDirs;
-    QSet<QString> excludedFiles;
-    QStringList excludedDirsList;
-    QStringList excludedFilesList;
+    QSet<QString> excludedDirs = QSet<QString>::fromList(config.getCanonicalPathList(CONFIG_EXCLUDEDIRS));
+    QSet<QString> excludedFiles = QSet<QString>::fromList(config.getCanonicalPathList(CONFIG_EXCLUDEFILES));
+
+    Generator::debug("Adding doc/image dirs found in exampledirs to imagedirs");
+    QSet<QString> exampleImageDirs;
+    QStringList exampleImageList = config.getExampleImageFiles(excludedDirs, excludedFiles);
+    for (int i = 0; i < exampleImageList.size(); ++i) {
+        if (exampleImageList[i].contains("doc/images")) {
+            QString t = exampleImageList[i].left(exampleImageList[i].lastIndexOf("doc/images") + 10);
+            if (!exampleImageDirs.contains(t)) {
+                exampleImageDirs.insert(t);
+            }
+        }
+    }
+    Generator::augmentImageDirs(exampleImageDirs);
 
     if (!Generator::singleExec() || !Generator::generating()) {
         QStringList headerList;
         QStringList sourceList;
 
-        Generator::debug("Reading excludedirs");
-        excludedDirsList = config.getCanonicalPathList(CONFIG_EXCLUDEDIRS);
-        foreach (const QString &excludeDir, excludedDirsList) {
-            QString p = QDir::fromNativeSeparators(excludeDir);
-            QDir tmp(p);
-            if (tmp.exists())
-                excludedDirs.insert(p);
-        }
-
-        Generator::debug("Reading excludefiles");
-        excludedFilesList = config.getCanonicalPathList(CONFIG_EXCLUDEFILES);
-        foreach (const QString& excludeFile, excludedFilesList) {
-            QString p = QDir::fromNativeSeparators(excludeFile);
-            excludedFiles.insert(p);
-        }
-
         Generator::debug("Reading headerdirs");
         headerList = config.getAllFiles(CONFIG_HEADERS,CONFIG_HEADERDIRS,excludedDirs,excludedFiles);
         QMap<QString,QString> headers;
@@ -430,20 +420,6 @@ static void processQdocconfFile(const QString &fileName)
                 sourceFileNames.insert(t,t);
             }
         }
-
-        Generator::debug("Adding doc/image dirs found in exampledirs to imagedirs");
-        QSet<QString> exampleImageDirs;
-        QStringList exampleImageList = config.getExampleImageFiles(excludedDirs, excludedFiles);
-        for (int i=0; i<exampleImageList.size(); ++i) {
-            if (exampleImageList[i].contains("doc/images")) {
-                QString t = exampleImageList[i].left(exampleImageList[i].lastIndexOf("doc/images")+10);
-                if (!exampleImageDirs.contains(t)) {
-                    exampleImageDirs.insert(t);
-                }
-            }
-        }
-        Generator::augmentImageDirs(exampleImageDirs);
-
         /*
           Parse each header file in the set using the appropriate parser and add it
           to the big tree.
@@ -504,34 +480,6 @@ static void processQdocconfFile(const QString &fileName)
         qdb->resolveIssues();
     }
     else {
-        Generator::debug("Reading excludedirs");
-        excludedDirsList = config.getCanonicalPathList(CONFIG_EXCLUDEDIRS);
-        foreach (const QString &excludeDir, excludedDirsList) {
-            QString p = QDir::fromNativeSeparators(excludeDir);
-            QDir tmp(p);
-            if (tmp.exists())
-                excludedDirs.insert(p);
-        }
-
-        Generator::debug("Reading excludefiles");
-        excludedFilesList = config.getCanonicalPathList(CONFIG_EXCLUDEFILES);
-        foreach (const QString& excludeFile, excludedFilesList) {
-            QString p = QDir::fromNativeSeparators(excludeFile);
-            excludedFiles.insert(p);
-        }
-
-        Generator::debug("Adding doc/image dirs found in exampledirs to imagedirs");
-        QSet<QString> exampleImageDirs;
-        QStringList exampleImageList = config.getExampleImageFiles(excludedDirs, excludedFiles);
-        for (int i=0; i<exampleImageList.size(); ++i) {
-            if (exampleImageList[i].contains("doc/images")) {
-                QString t = exampleImageList[i].left(exampleImageList[i].lastIndexOf("doc/images")+10);
-                if (!exampleImageDirs.contains(t)) {
-                    exampleImageDirs.insert(t);
-                }
-            }
-        }
-        Generator::augmentImageDirs(exampleImageDirs);
         qdb->resolveStuff();
     }
 
@@ -574,168 +522,157 @@ static void processQdocconfFile(const QString &fileName)
     Generator::debug("qdoc classes terminated");
 }
 
-extern Q_CORE_EXPORT QBasicAtomicInt qt_qhash_seed;
-QT_END_NAMESPACE
-
-int main(int argc, char **argv)
+class QDocCommandLineParser : public QCommandLineParser
 {
-    QT_USE_NAMESPACE
+public:
+    QDocCommandLineParser();
+    void process(const QCoreApplication &app);
 
-#ifndef QT_BOOTSTRAPPED
-    qt_qhash_seed.testAndSetRelaxed(-1, 0); // set the hash seed to 0 if it wasn't set yet
-#endif
-    QCoreApplication app(argc, argv);
-    app.setApplicationVersion(QStringLiteral(QT_VERSION_STR));
+private:
+    QCommandLineOption defineOption, dependsOption, highlightingOption;
+    QCommandLineOption showInternalOption, redirectDocumentationToDevNullOption;
+    QCommandLineOption noExamplesOption, indexDirOption, installDirOption;
+    QCommandLineOption obsoleteLinksOption, outputDirOption, outputFormatOption;
+    QCommandLineOption noLinkErrorsOption, autoLinkErrorsOption, debugOption;
+    QCommandLineOption prepareOption, generateOption, logProgressOption;
+    QCommandLineOption singleExecOption, writeQaPagesOption;
+};
 
-    /*
-      Create code parsers for the languages to be parsed,
-      and create a tree for C++.
-     */
-    CppCodeParser cppParser;
-    QmlCodeParser qmlParser;
-    PureDocParser docParser;
+QDocCommandLineParser::QDocCommandLineParser()
+    : QCommandLineParser(),
+      defineOption(QStringList() << QStringLiteral("D")),
+      dependsOption(QStringList() << QStringLiteral("depends")),
+      highlightingOption(QStringList() << QStringLiteral("highlighting")),
+      showInternalOption(QStringList() << QStringLiteral("showinternal")),
+      redirectDocumentationToDevNullOption(QStringList() << QStringLiteral("redirect-documentation-to-dev-null")),
+      noExamplesOption(QStringList() << QStringLiteral("no-examples")),
+      indexDirOption(QStringList() << QStringLiteral("indexdir")),
+      installDirOption(QStringList() << QStringLiteral("installdir")),
+      obsoleteLinksOption(QStringList() << QStringLiteral("obsoletelinks")),
+      outputDirOption(QStringList() << QStringLiteral("outputdir")),
+      outputFormatOption(QStringList() << QStringLiteral("outputformat")),
+      noLinkErrorsOption(QStringList() << QStringLiteral("no-link-errors")),
+      autoLinkErrorsOption(QStringList() << QStringLiteral("autolink-errors")),
+      debugOption(QStringList() << QStringLiteral("debug")),
+      prepareOption(QStringList() << QStringLiteral("prepare")),
+      generateOption(QStringList() << QStringLiteral("generate")),
+      logProgressOption(QStringList() << QStringLiteral("log-progress")),
+      singleExecOption(QStringList() << QStringLiteral("single-exec")),
+      writeQaPagesOption(QStringList() << QStringLiteral("write-qa-pages"))
+{
+    setApplicationDescription(QCoreApplication::translate("qdoc", "Qt documentation generator"));
+    addHelpOption();
+    addVersionOption();
 
-    /*
-      Create code markers for plain text, C++,
-      javascript, and QML.
-     */
-    PlainCodeMarker plainMarker;
-    CppCodeMarker cppMarker;
-    JsCodeMarker jsMarker;
-    QmlCodeMarker qmlMarker;
+    setSingleDashWordOptionMode(QCommandLineParser::ParseAsLongOptions);
 
-    HtmlGenerator htmlGenerator;
+    addPositionalArgument("file1.qdocconf ...", QCoreApplication::translate("qdoc", "Input files"));
 
-    QCommandLineParser parser;
-    parser.setApplicationDescription(QCoreApplication::translate("qdoc", "Qt documentation generator"));
-    parser.addHelpOption();
-    parser.addVersionOption();
-
-    parser.setSingleDashWordOptionMode(QCommandLineParser::ParseAsLongOptions);
-
-    parser.addPositionalArgument("file1.qdocconf ...", QCoreApplication::translate("qdoc", "Input files"));
-
-    QCommandLineOption defineOption(QStringList() << QStringLiteral("D"));
     defineOption.setDescription(QCoreApplication::translate("qdoc", "Define the argument as a macro while parsing sources"));
     defineOption.setValueName(QStringLiteral("macro[=def]"));
-    parser.addOption(defineOption);
+    addOption(defineOption);
 
-    QCommandLineOption dependsOption(QStringList() << QStringLiteral("depends"));
     dependsOption.setDescription(QCoreApplication::translate("qdoc", "Specify dependent modules"));
     dependsOption.setValueName(QStringLiteral("module"));
-    parser.addOption(dependsOption);
+    addOption(dependsOption);
 
-    QCommandLineOption highlightingOption(QStringList() << QStringLiteral("highlighting"));
     highlightingOption.setDescription(QCoreApplication::translate("qdoc", "Turn on syntax highlighting (makes qdoc run slower)"));
-    parser.addOption(highlightingOption);
+    addOption(highlightingOption);
 
-    QCommandLineOption showInternalOption(QStringList() << QStringLiteral("showinternal"));
     showInternalOption.setDescription(QCoreApplication::translate("qdoc", "Include content marked internal"));
-    parser.addOption(showInternalOption);
+    addOption(showInternalOption);
 
-    QCommandLineOption redirectDocumentationToDevNullOption(QStringList() << QStringLiteral("redirect-documentation-to-dev-null"));
     redirectDocumentationToDevNullOption.setDescription(QCoreApplication::translate("qdoc", "Save all documentation content to /dev/null. Useful if someone is interested in qdoc errors only."));
-    parser.addOption(redirectDocumentationToDevNullOption);
+    addOption(redirectDocumentationToDevNullOption);
 
-    QCommandLineOption noExamplesOption(QStringList() << QStringLiteral("no-examples"));
     noExamplesOption.setDescription(QCoreApplication::translate("qdoc", "Do not generate documentation for examples"));
-    parser.addOption(noExamplesOption);
+    addOption(noExamplesOption);
 
-    QCommandLineOption indexDirOption(QStringList() << QStringLiteral("indexdir"));
     indexDirOption.setDescription(QCoreApplication::translate("qdoc", "Specify a directory where QDoc should search for index files to load"));
     indexDirOption.setValueName(QStringLiteral("dir"));
-    parser.addOption(indexDirOption);
+    addOption(indexDirOption);
 
-    QCommandLineOption installDirOption(QStringList() << QStringLiteral("installdir"));
     installDirOption.setDescription(QCoreApplication::translate("qdoc", "Specify the directory where the output will be after running \"make install\""));
     installDirOption.setValueName(QStringLiteral("dir"));
-    parser.addOption(installDirOption);
+    addOption(installDirOption);
 
-    QCommandLineOption obsoleteLinksOption(QStringList() << QStringLiteral("obsoletelinks"));
     obsoleteLinksOption.setDescription(QCoreApplication::translate("qdoc", "Report links from obsolete items to non-obsolete items"));
-    parser.addOption(obsoleteLinksOption);
+    addOption(obsoleteLinksOption);
 
-    QCommandLineOption outputDirOption(QStringList() << QStringLiteral("outputdir"));
     outputDirOption.setDescription(QCoreApplication::translate("qdoc", "Specify output directory, overrides setting in qdocconf file"));
     outputDirOption.setValueName(QStringLiteral("dir"));
-    parser.addOption(outputDirOption);
+    addOption(outputDirOption);
 
-    QCommandLineOption outputFormatOption(QStringList() << QStringLiteral("outputformat"));
     outputFormatOption.setDescription(QCoreApplication::translate("qdoc", "Specify output format, overrides setting in qdocconf file"));
     outputFormatOption.setValueName(QStringLiteral("format"));
-    parser.addOption(outputFormatOption);
+    addOption(outputFormatOption);
 
-    QCommandLineOption noLinkErrorsOption(QStringList() << QStringLiteral("no-link-errors"));
     noLinkErrorsOption.setDescription(QCoreApplication::translate("qdoc", "Do not print link errors (i.e. missing targets)"));
-    parser.addOption(noLinkErrorsOption);
+    addOption(noLinkErrorsOption);
 
-    QCommandLineOption autoLinkErrorsOption(QStringList() << QStringLiteral("autolink-errors"));
     autoLinkErrorsOption.setDescription(QCoreApplication::translate("qdoc", "Show errors when automatic linking fails"));
-    parser.addOption(autoLinkErrorsOption);
+    addOption(autoLinkErrorsOption);
 
-    QCommandLineOption debugOption(QStringList() << QStringLiteral("debug"));
     debugOption.setDescription(QCoreApplication::translate("qdoc", "Enable debug output"));
-    parser.addOption(debugOption);
+    addOption(debugOption);
 
-    QCommandLineOption prepareOption(QStringList() << QStringLiteral("prepare"));
     prepareOption.setDescription(QCoreApplication::translate("qdoc", "Run qdoc only to generate an index file, not the docs"));
-    parser.addOption(prepareOption);
+    addOption(prepareOption);
 
-    QCommandLineOption generateOption(QStringList() << QStringLiteral("generate"));
     generateOption.setDescription(QCoreApplication::translate("qdoc", "Run qdoc to read the index files and generate the docs"));
-    parser.addOption(generateOption);
+    addOption(generateOption);
 
-    QCommandLineOption logProgressOption(QStringList() << QStringLiteral("log-progress"));
     logProgressOption.setDescription(QCoreApplication::translate("qdoc", "Log progress on stderr."));
-    parser.addOption(logProgressOption);
+    addOption(logProgressOption);
 
-    QCommandLineOption singleExecOption(QStringList() << QStringLiteral("single-exec"));
     singleExecOption.setDescription(QCoreApplication::translate("qdoc", "Run qdoc once over all the qdoc conf files."));
-    parser.addOption(singleExecOption);
+    addOption(singleExecOption);
 
-    QCommandLineOption writeQaPagesOption(QStringList() << QStringLiteral("write-qa-pages"));
     writeQaPagesOption.setDescription(QCoreApplication::translate("qdoc", "Write QA pages."));
-    parser.addOption(writeQaPagesOption);
+    addOption(writeQaPagesOption);
+}
 
-    parser.process(app);
+void QDocCommandLineParser::process(const QCoreApplication &app)
+{
+    QCommandLineParser::process(app);
 
-    defines += parser.values(defineOption);
-    dependModules += parser.values(dependsOption);
-    highlighting = parser.isSet(highlightingOption);
-    showInternal = parser.isSet(showInternalOption);
-    singleExec = parser.isSet(singleExecOption);
-    writeQaPages = parser.isSet(writeQaPagesOption);
-    redirectDocumentationToDevNull = parser.isSet(redirectDocumentationToDevNullOption);
-    Config::generateExamples = !parser.isSet(noExamplesOption);
-    foreach (const QString &indexDir, parser.values(indexDirOption)) {
+    defines += values(defineOption);
+    dependModules += values(dependsOption);
+    highlighting = isSet(highlightingOption);
+    showInternal = isSet(showInternalOption);
+    singleExec = isSet(singleExecOption);
+    writeQaPages = isSet(writeQaPagesOption);
+    redirectDocumentationToDevNull = isSet(redirectDocumentationToDevNullOption);
+    Config::generateExamples = !isSet(noExamplesOption);
+    foreach (const QString &indexDir, values(indexDirOption)) {
         if (QFile::exists(indexDir))
             indexDirs += indexDir;
         else
             qDebug() << "Cannot find index directory" << indexDir;
     }
-    if (parser.isSet(installDirOption))
-        Config::installDir = parser.value(installDirOption);
-    obsoleteLinks = parser.isSet(obsoleteLinksOption);
-    if (parser.isSet(outputDirOption))
-        Config::overrideOutputDir = parser.value(outputDirOption);
-    foreach (const QString &format, parser.values(outputFormatOption))
+    if (isSet(installDirOption))
+        Config::installDir = value(installDirOption);
+    obsoleteLinks = isSet(obsoleteLinksOption);
+    if (isSet(outputDirOption))
+        Config::overrideOutputDir = value(outputDirOption);
+    foreach (const QString &format, values(outputFormatOption))
         Config::overrideOutputFormats.insert(format);
-    noLinkErrors = parser.isSet(noLinkErrorsOption);
-    autolinkErrors = parser.isSet(autoLinkErrorsOption);
-    if (parser.isSet(debugOption))
+    noLinkErrors = isSet(noLinkErrorsOption);
+    autolinkErrors = isSet(autoLinkErrorsOption);
+    if (isSet(debugOption))
         Generator::startDebugging(QString("command line"));
-    if (parser.isSet(prepareOption))
+    if (isSet(prepareOption))
         Generator::setQDocPass(Generator::Prepare);
-    if (parser.isSet(generateOption))
+    if (isSet(generateOption))
         Generator::setQDocPass(Generator::Generate);
-    if (parser.isSet(singleExecOption)) {
+    if (isSet(singleExecOption)) {
         Generator::setSingleExec();
-        if (parser.isSet(indexDirOption))
+        if (isSet(indexDirOption))
             qDebug() << "WARNING: -indexdir option ignored: Index files are not used in -single-exec mode.";
     }
-    if (parser.isSet(writeQaPagesOption))
+    if (isSet(writeQaPagesOption))
         Generator::setWriteQaPages();
-    if (parser.isSet(logProgressOption))
+    if (isSet(logProgressOption))
         Location::startLoggingProgress();
 
     /*
@@ -755,7 +692,47 @@ int main(int argc, char **argv)
         defaults.insert(CONFIG_OUTPUTFORMATS, QLatin1String("HTML"));
         defaults.insert(CONFIG_TABSIZE, QLatin1String("8"));
     }
+}
 
+extern Q_CORE_EXPORT QBasicAtomicInt qt_qhash_seed;
+QT_END_NAMESPACE
+
+int main(int argc, char **argv)
+{
+    QT_USE_NAMESPACE
+
+    // Initialize Qt:
+#ifndef QT_BOOTSTRAPPED
+    qt_qhash_seed.testAndSetRelaxed(-1, 0); // set the hash seed to 0 if it wasn't set yet
+#endif
+    QCoreApplication app(argc, argv);
+    app.setApplicationVersion(QLatin1String(QT_VERSION_STR));
+
+    // Instantiate various singletons (used via static methods):
+    /*
+      Create code parsers for the languages to be parsed,
+      and create a tree for C++.
+     */
+    CppCodeParser cppParser;
+    QmlCodeParser qmlParser;
+    PureDocParser docParser;
+
+    /*
+      Create code markers for plain text, C++,
+      javascript, and QML.
+     */
+    PlainCodeMarker plainMarker;
+    CppCodeMarker cppMarker;
+    JsCodeMarker jsMarker;
+    QmlCodeMarker qmlMarker;
+
+    HtmlGenerator htmlGenerator;
+
+    // Set the globals declared at the top of this file:
+    QDocCommandLineParser parser;
+    parser.process(app);
+
+    // Get the list of files to act on:
     QStringList qdocFiles = parser.positionalArguments();
     if (qdocFiles.isEmpty())
         parser.showHelp();
@@ -763,9 +740,7 @@ int main(int argc, char **argv)
     if (singleExec)
         qdocFiles = Config::loadMaster(qdocFiles.at(0));
 
-    /*
-      Main loop is now modified to handle single exec mode.
-     */
+    // Main loop (adapted, when needed, to handle single exec mode):
     if (Generator::singleExec())
         Generator::setQDocPass(Generator::Prepare);
     foreach (const QString &qf, qdocFiles) {
@@ -782,6 +757,7 @@ int main(int argc, char **argv)
         }
     }
 
+    // Tidy everything away:
 #ifndef QT_NO_TRANSLATION
     if (!translators.isEmpty()) {
         for (int i=0; i<translators.size(); ++i) {
