@@ -1,31 +1,26 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the tools applications of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL21$
+** $QT_BEGIN_LICENSE:GPL-EXCEPT$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** As a special exception, The Qt Company gives you certain additional
-** rights. These rights are described in The Qt Company LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3 as published by the Free Software
+** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -2438,7 +2433,7 @@ QString PropertyNode::qualifiedDataType() const
 }
 
 bool QmlTypeNode::qmlOnly = false;
-QMultiMap<QString,Node*> QmlTypeNode::inheritedBy;
+QMultiMap<const Node*, Node*> QmlTypeNode::inheritedBy;
 
 /*!
   Constructs a Qml class node. The new node has the given
@@ -2484,18 +2479,18 @@ void QmlTypeNode::terminate()
   Record the fact that QML class \a base is inherited by
   QML class \a sub.
  */
-void QmlTypeNode::addInheritedBy(const QString& base, Node* sub)
+void QmlTypeNode::addInheritedBy(const Node *base, Node* sub)
 {
     if (sub->isInternal())
         return;
-    if (inheritedBy.constFind(base,sub) == inheritedBy.constEnd())
-        inheritedBy.insert(base,sub);
+    if (!inheritedBy.contains(base, sub))
+        inheritedBy.insert(base, sub);
 }
 
 /*!
   Loads the list \a subs with the nodes of all the subclasses of \a base.
  */
-void QmlTypeNode::subclasses(const QString& base, NodeList& subs)
+void QmlTypeNode::subclasses(const Node *base, NodeList &subs)
 {
     subs.clear();
     if (inheritedBy.count(base) > 0) {
@@ -2503,13 +2498,6 @@ void QmlTypeNode::subclasses(const QString& base, NodeList& subs)
     }
 }
 
-QmlTypeNode* QmlTypeNode::qmlBaseNode()
-{
-    if (!qmlBaseNode_ && !qmlBaseName_.isEmpty()) {
-        qmlBaseNode_ = QDocDatabase::qdocDB()->findQmlType(qmlBaseName_);
-    }
-    return qmlBaseNode_;
-}
 
 /*!
   If this QML type node has a base type node,
