@@ -1,31 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the tools applications of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL21$
+** $QT_BEGIN_LICENSE:LGPL$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 3 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL3 included in the
+** packaging of this file. Please review the following information to
+** ensure the GNU Lesser General Public License version 3 requirements
+** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
 **
-** As a special exception, The Qt Company gives you certain additional
-** rights. These rights are described in The Qt Company LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 2.0 or (at your option) the GNU General
+** Public license version 3 or any later version approved by the KDE Free
+** Qt Foundation. The licenses are as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-2.0.html and
+** https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -51,7 +57,8 @@ public:
     QSet<QtProperty *> m_parentItems;
     QList<QtProperty *> m_subItems;
 
-    QString m_toolTip;
+    QString m_valueToolTip;
+    QString m_descriptionToolTip;
     QString m_statusTip;
     QString m_whatsThis;
     QString m_name;
@@ -100,7 +107,11 @@ public:
     \row
     \li statusTip() \li setStatusTip()
     \row
-    \li toolTip() \li setToolTip()
+    \li descriptionToolTip() \li setDescriptionToolTip()
+    \row
+    \li valueToolTip() \li setValueToolTip()
+    \row
+    \li toolTip() \deprecated in 5.6 \li setToolTip() \deprecated in 5.6
     \row
     \li whatsThis() \li setWhatsThis()
     \row
@@ -192,14 +203,35 @@ QtAbstractPropertyManager *QtProperty::propertyManager() const
     return d_ptr->m_manager;
 }
 
-/*!
-    Returns the property's  tool tip.
+/* Note: As of 17.7.2015 for Qt 5.6, the existing 'toolTip' of the Property
+ * Browser solution was split into valueToolTip() and descriptionToolTip()
+ * to be able to implement custom tool tip for QTBUG-45442. This could
+ * be back-ported to the solution. */
 
-    \sa setToolTip()
+/*!
+    Returns the property value's  tool tip.
+
+    This is suitable for tool tips over the value (item delegate).
+
+    \since 5.6
+    \sa setValueToolTip()
 */
-QString QtProperty::toolTip() const
+QString QtProperty::valueToolTip() const
 {
-    return d_ptr->m_toolTip;
+    return d_ptr->m_valueToolTip;
+}
+
+/*!
+    Returns the property description's  tool tip.
+
+    This is suitable for tool tips over the description (label).
+
+    \since 5.6
+    \sa setDescriptionToolTip()
+*/
+QString QtProperty::descriptionToolTip() const
+{
+    return d_ptr->m_descriptionToolTip;
 }
 
 /*!
@@ -289,16 +321,32 @@ QString QtProperty::valueText() const
 }
 
 /*!
-    Sets the property's tool tip to the given \a text.
+    Sets the property value's tool tip to the given \a text.
 
-    \sa toolTip()
+    \since 5.6
+    \sa valueToolTip()
 */
-void QtProperty::setToolTip(const QString &text)
+void QtProperty::setValueToolTip(const QString &text)
 {
-    if (d_ptr->m_toolTip == text)
+    if (d_ptr->m_valueToolTip == text)
         return;
 
-    d_ptr->m_toolTip = text;
+    d_ptr->m_valueToolTip = text;
+    propertyChanged();
+}
+
+/*!
+    Sets the property description's tool tip to the given \a text.
+
+    \since 5.6
+    \sa descriptionToolTip()
+*/
+void QtProperty::setDescriptionToolTip(const QString &text)
+{
+    if (d_ptr->m_descriptionToolTip == text)
+        return;
+
+    d_ptr->m_descriptionToolTip = text;
     propertyChanged();
 }
 
