@@ -1,31 +1,26 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the tools applications of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL21$
+** $QT_BEGIN_LICENSE:GPL-EXCEPT$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** As a special exception, The Qt Company gives you certain additional
-** rights. These rights are described in The Qt Company LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3 as published by the Free Software
+** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -90,7 +85,7 @@ static void parseSectionHeader(const uchar *s, ElfSectionHeader *sh, const ElfDa
 {
     sh->index = getWord(s, context);
     sh->type = getWord(s, context);
-    sh->flags = getOffset(s, context);
+    sh->flags = quint32(getOffset(s, context));
     sh->addr = getAddress(s, context);
     sh->offset = getOffset(s, context);
     sh->size = getOffset(s, context);
@@ -116,13 +111,13 @@ public:
         if (!file.open(QIODevice::ReadOnly))
             return false;
 
-        fdlen = file.size();
-        ustart = file.map(0, fdlen);
+        fdlen = quint64(file.size());
+        ustart = file.map(0, qint64(fdlen));
         if (ustart == 0) {
             // Try reading the data into memory instead.
             raw = file.readAll();
             start = raw.constData();
-            fdlen = raw.size();
+            fdlen = quint64(raw.size());
         }
         return true;
     }
@@ -290,7 +285,7 @@ ElfReader::Result ElfReader::readIt()
                 m_elfData.symbolsType = BuildIdSymbols;
                 if (sh.size > 16)
                     m_elfData.buildId = QByteArray(mapper.start + sh.offset + 16,
-                                                   sh.size - 16).toHex();
+                                                   int(sh.size) - 16).toHex();
             }
             m_elfData.sectionHeaders.append(sh);
         }
@@ -319,7 +314,7 @@ QByteArray ElfReader::readSection(const QByteArray &name)
         return QByteArray();
 
     const ElfSectionHeader &section = m_elfData.sectionHeaders.at(i);
-    return QByteArray(mapper.start + section.offset, section.size);
+    return QByteArray(mapper.start + section.offset, int(section.size));
 }
 
 static QByteArray cutout(const char *s)
