@@ -1,31 +1,26 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the tools applications of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL21$
+** $QT_BEGIN_LICENSE:GPL-EXCEPT$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** As a special exception, The Qt Company gives you certain additional
-** rights. These rights are described in The Qt Company LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3 as published by the Free Software
+** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -985,10 +980,12 @@ static bool deployTranslations(const QString &sourcePath, quint64 usedQtModules,
 
 struct DeployResult
 {
-    DeployResult() : success(false), directlyUsedQtLibraries(0), usedQtLibraries(0), deployedQtLibraries(0) {}
+    DeployResult() : success(false), isDebug(false), directlyUsedQtLibraries(0), usedQtLibraries(0),
+        deployedQtLibraries(0) {}
     operator bool() const { return success; }
 
     bool success;
+    bool isDebug;
     quint64 directlyUsedQtLibraries;
     quint64 usedQtLibraries;
     quint64 deployedQtLibraries;
@@ -1124,17 +1121,17 @@ static bool updateLibrary(const QString &sourceFileName, const QString &targetDi
 // 'QtQuick/Controls' ==> 1, or 'QtQuick/Controls.2' ==> 2.
 static inline int quickControlsImportPath(const QString &ip)
 {
+    if (ip.contains(QLatin1String("Qt/labs/calendar"))
+        || ip.contains(QLatin1String("Qt/labs/folderlistmodel"))
+        || ip.contains(QLatin1String("Qt/labs/settings"))
+        || ip.contains(QLatin1String("QtQuick/Templates.2"))
+        || ip.contains(QLatin1String("QtQuick/Controls.2"))) {
+        return 2;
+    }
     if (ip.endsWith(QLatin1String("QtQuick/Dialogs")) || ip.contains(QLatin1String("QtQuick/Dialogs/"))
         || ip.contains(QLatin1String("QtQuick/Controls"))) {
         return 1; // Dialogs only in v1, so far; no version number on directory: v1.
     }
-    if (ip.contains(QLatin1String("Qt/labs/calendar"))
-        || ip.contains(QLatin1String("Qt/labs/controls"))
-        || ip.contains(QLatin1String("Qt/labs/folderlistmodel"))
-        || ip.contains(QLatin1String("Qt/labs/settings"))
-        || ip.contains(QLatin1String("Qt/labs/templates"))) {
-        return 2;
-    }
     return 0; // Non-controls import
 }
 
@@ -1171,6 +1168,7 @@ static DeployResult deploy(const Options &options,
     }
 
     const bool isDebug = options.debugDetection == Options::DebugDetectionAuto ? detectedDebug: options.debugDetection == Options::DebugDetectionForceDebug;
+    result.isDebug = isDebug;
     const DebugMatchMode debugMatchMode = isDebug ? MatchDebug : MatchRelease;
 
     // Determine application type, check Quick2 is used by looking at the
@@ -1502,16 +1500,18 @@ static bool deployWebProcess(const QMap<QString, QString> &qmakeVariables,
 }
 
 static bool deployWebEngineCore(const QMap<QString, QString> &qmakeVariables,
-                                const Options &options, QString *errorMessage)
+                                const Options &options, bool isDebug, QString *errorMessage)
 {
     static const char *installDataFiles[] = {"icudtl.dat",
                                              "qtwebengine_resources.pak",
                                              "qtwebengine_resources_100p.pak",
                                              "qtwebengine_resources_200p.pak"};
-
+    QByteArray webEngineProcessName(webEngineProcessC);
+    if (isDebug)
+        webEngineProcessName.append('d');
     if (optVerboseLevel)
-        std::wcout << "Deploying: " << webEngineProcessC << "...\n";
-    if (!deployWebProcess(qmakeVariables, webEngineProcessC, options, errorMessage))
+        std::wcout << "Deploying: " << webEngineProcessName.constData() << "...\n";
+    if (!deployWebProcess(qmakeVariables, webEngineProcessName, options, errorMessage))
         return false;
     const QString resourcesSubDir = QStringLiteral("/resources");
     const QString resourcesSourceDir
@@ -1618,7 +1618,7 @@ int main(int argc, char **argv)
     }
 
     if (result.deployedQtLibraries & QtWebEngineCoreModule) {
-        if (!deployWebEngineCore(qmakeVariables, options, &errorMessage)) {
+        if (!deployWebEngineCore(qmakeVariables, options, result.isDebug, &errorMessage)) {
             std::wcerr << errorMessage << '\n';
             return 1;
         }
